import java.io.IOException;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.FSDataInputStream;
import org.apache.hadoop.fs.FileSystem;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.BytesWritable;
import org.apache.hadoop.io.IOUtils;
import org.apache.hadoop.io.NullWritable;
import org.apache.hadoop.mapred.FileSplit;
import org.apache.hadoop.mapred.RecordReader;


public class WholeFileRecordReader implements RecordReader<NullWritable, BytesWritable>
{
	private FileSplit fileSplit;
	private FSDataInputStream in;
	
	
	public WholeFileRecordReader(FileSplit fileSplit, Configuration job)throws IOException
	{
		super();
		this.fileSplit = fileSplit;
		Path file = fileSplit.getPath();
		FileSystem fs = file.getFileSystem(job);
		this.in = fs.open(file);
	}

	public void close() throws IOException {
		IOUtils.closeStream(in);

	}

	public NullWritable createKey() {

		return NullWritable.get();
	}

	public BytesWritable createValue() {

		return new BytesWritable();
	}

	public long getPos() throws IOException {
		
		return in.getPos();
	}

	public float getProgress() throws IOException {
		return in.getPos()/fileSplit.getLength();
	}

	public boolean next(NullWritable key, BytesWritable value) throws IOException 
	{
		if(in.getPos() == 0)
		{
			byte[] contents = new byte[(int)fileSplit.getLength()];
			IOUtils.readFully(in,contents,0,contents.length);
			value.set(contents,0,contents.length);
			return true;
		}
		return false;
	}
}
